# Avro to Bigquery

[![CI pipeline status](https://github.com/wayfair-incubator/avro-to-bigquery/workflows/CI/badge.svg?branch=main)](ci)
[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.0-4baaaa.svg)](CODE_OF_CONDUCT.md)

## About The Project

Avro to bigquery is a simple project to create a bigquery schema from an avro schema.

## Getting Started

To get a local copy up and running follow these simple steps.

### Installation

1. Clone the repo

   ```sh
   git clone https://github.com/wayfair-incubator/avro-to-bigquery.git
   ```

2. Install package

   ```sh
   pip install avro-to-bigquery
   ```

## Usage

...

## Roadmap

See the [open issues](https://github.com/wayfair-incubator/avro-to-bigquery//issues) for a list of proposed features (and known issues).

## Contributing

Contributions are what make the open source community such an amazing place to learn, inspire, and create. Any contributions you make are **greatly appreciated**. For detailed contributing guidelines, please see [CONTRIBUTING.md](CONTRIBUTING.md)

## License

Distributed under the `MIT` License. See `LICENSE` for more information.

## Contact

Colm O'Connor

Project Link: [https://github.com/wayfair-incubator/avro-to-bigquery/](https://github.com/wayfair-incubator/avro-to-bigquery/)

## Acknowledgements

This template adapted from
[https://github.com/othneildrew/Best-README-Template](https://github.com/othneildrew/Best-README-Template)
